@@ -1,5 +1,5 @@
 package QBit::Application::Model::DBManager::Users;
-$QBit::Application::Model::DBManager::Users::VERSION = '0.004';
+$QBit::Application::Model::DBManager::Users::VERSION = '0.005';
 use qbit;
 
 use base qw(QBit::Application::Model::DBManager);
@@ -58,7 +58,7 @@ sub query {
     my $filter = $self->db->filter($opts{'filter'});
 
     unless ($self->check_rights('users_view')) {
-        $filter->and(['id' => '=' => \$self->get_option('cur_user', {})->{'id'}]);
+        $filter->and(['id' => '=' => \$self->cur_user()->{'id'}]);
     }
 
     return $self->db->query->select(
